@@ -59,22 +59,7 @@ lock_pref("gfx.webrender.multithreading", false);
 
 // Environment Settings
 
-// Proxy Pac
-//lock_pref("network.proxy.type", 2);
-//lock_pref("network.proxy.autoconfig_url", "file:///etc/treuchtlingen/proxy.pac");
-
-lock_pref("network.proxy.ftp", "proxy.dmz.treuchtlingen.stadt");
-lock_pref("network.proxy.ftp_port", 3128);
-lock_pref("network.proxy.http", "proxy.dmz.treuchtlingen.stadt");
-lock_pref("network.proxy.http_port", 3128);
-lock_pref("network.proxy.share_proxy_settings", true);
-lock_pref("network.proxy.socks", "proxy.dmz.treuchtlingen.stadt");
-lock_pref("network.proxy.socks_port", 3128);
-lock_pref("network.proxy.ssl", "proxy.dmz.treuchtlingen.stadt");
-lock_pref("network.proxy.ssl_port", 3128);
-lock_pref("network.proxy.type", 1);
-
-lock_pref("network.proxy.no_proxies_on", ".stadt, 192.168.0.0/16, up, 157.40.1.0/24, koha.treuchtlingen.de");
+// Proxy Setting have been moved to policies.json
 
 // Security Settings
 lock_pref("network.cookie.cookieBehavior", 2);
